@@ -25,7 +25,9 @@
 #ifndef GCU_APPLICATION_H
 #define GCU_APPLICATION_H
 
+#include <set>
 #include <string>
+#include <gtk/gtkmain.h>
 #include <gtk/gtkwindow.h>
 
 using namespace std;
@@ -102,12 +104,28 @@ if they use the FileChooser.
 @param dir: the path to the new current directory.
 */
 	void SetCurDir (char const* dir);
-
+	void ShowURI (string& uri);
+	void OnBug (char *uri = PACKAGE_BUGREPORT)
+		{string s (uri); ShowURI (s);}
+	void OnWeb (char *uri = "http://gchemutils.nongnu.org/")
+		{string s (uri); ShowURI (s);}
+	void OnMail (char *MailAddress = "mailto:gchemutils-main@nongnu.org");
+	bool HasMailAgent () {return MailAgent.length () > 0;}
+	bool HasWebBrowser () {return WebBrowser.length () > 0;}
+	void AddDocument (Document *Doc) {m_Docs.insert (Doc);}
+	void RemoveDocument (Document *Doc) {m_Docs.erase (Doc); if (m_Docs.size () == 0) NoMoreDocsEvent ();}
+	virtual void NoMoreDocsEvent () {gtk_main_quit ();}
+	
 private:
 	string Name;
 	string HelpBrowser;
 	string HelpFilename;
 	char *CurDir;
+
+protected:
+	string WebBrowser;
+	string MailAgent;
+	set <Document*> m_Docs;
 };
 
 }	// namespace gcu
