@@ -4,21 +4,19 @@
  * Gnome Chemistry Utils
  * chemistry/document.h 
  *
- * Copyright (C) 2004
+ * Copyright (C) 2004 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * This program is free software; you can redistribute it and/or 
+ * modify it under the terms of the GNU General Public License as 
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
+ * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
@@ -29,11 +27,15 @@
 #define GCU_DOCUMENT_H
 
 #include "object.h"
+#include <string>
 
 using namespace std;
 
 namespace gcu
 {
+
+class Application;
+
 /*!\class Document gcu/document.h
 This class is the base document class.
 */
@@ -42,9 +44,11 @@ class Document: public Object
 friend class gcu::Object;
 public:
 /*!
+@param App: the Appllcation which owns the new document.
+
 The default constructor. Creates an empty document.
 */
-	Document ();
+	Document (Application *App = NULL);
 /*!
 The destructor of Document.
 */
@@ -76,6 +80,10 @@ to avoid errors on the next paste event.
 */
 	void EmptyTranslationTable() {m_TranslationTable.clear();}
 
+	void SetTitle (string& title) {m_Title = title;}
+	void SetTitle (char const *title) {m_Title = title;}
+	string &GetTitle () {return m_Title;}
+
 private:
 
 /*!
@@ -91,6 +99,10 @@ GetNewId returns the translated id
 
 private:
 	map <string, string> m_TranslationTable;//used when Ids translations are necessary (on pasting...)
+
+protected:
+	Application *m_App;
+	string m_Title;
 };
 
 }
