@@ -31,6 +31,7 @@
 #include <vector>
 #include "chemistry.h"
 #include "isotope.h"
+#include "value.h"
 
 using namespace std;
 
@@ -150,6 +151,12 @@ public:
 	Loads the isotopes database.
 	*/
 	static void LoadIsotopes ();
+#ifdef WITH_BODR
+	/*!
+	Loads the Blue Obelisk Database.
+	*/
+	static void LoadBODR ();
+#endif
 	/*!
 	Loads all databases.
 	*/
@@ -249,6 +256,13 @@ public:
 	For most elements, only the first is known.
 	*/
 	GcuDimensionalValue const *GetElectronAffinity (unsigned rank = 1);
+	/*!
+	@param property_name: the name of the property as used in the Blue
+	Obelisk Data Repository (without the "bo:" prefix).
+
+	@return the requested property if known, or NULL.
+	*/
+	Value *const GetProperty (char const *property_name) {return props[property_name];}
 
 private:
 	unsigned char m_Z, m_nve, m_tve, m_maxve;
@@ -267,6 +281,7 @@ private:
 	vector<GcuDimensionalValue> m_ei;
 	vector<GcuDimensionalValue> m_ae;
 	map<string, string> names;
+	map<string, Value*> props;
 	string ElecConfig;
 };
 
