@@ -2,9 +2,7 @@
  * Gnome Chemisty Utils
  * moz-plugin.c 
  *
- * Copyright (C) 2002-2005
- *
- * Developed by Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2005 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,7 +24,6 @@
 #include "npapi.h"
 #include "npupp.h"
 #include <unistd.h>
-#include <string.h>
 
 static NPNetscapeFuncs mozilla_funcs;
 static int pid = 0;
@@ -166,7 +163,7 @@ static NPError ChemNewStream (NPP instance, NPMIMEType type, NPStream *stream,
 
 static void ChemPrint (NPP instance, NPPrint *platformPrint)
 {
-// TODO: implement !!!
+#warning TODO: implement !!!
 }
 
 static void ChemStreamAsFile (NPP instance, NPStream *stream, const char *fname)
