@@ -180,19 +180,19 @@ gcLinesDlg::gcLinesDlg (gcApplication *App, gcDocument* pDoc): Dialog (App, DATA
 	LineR = (GtkEntry *) glade_xml_get_widget (xml, "radius");
 	Edges = (GtkCheckButton *) glade_xml_get_widget (xml, "edges");
 	g_signal_connect (G_OBJECT (Edges), "toggled", G_CALLBACK (on_edges_toggled), this);
-	EdgesColor = (GtkColorButton *) glade_xml_get_widget (xml, "edges_color");
+	EdgesColor = (GtkColorButton *) glade_xml_get_widget (xml, "edges-color");
 	gtk_widget_set_sensitive (GTK_WIDGET (EdgesColor), false);
 	EdgesR = (GtkEntry *) glade_xml_get_widget (xml, "edges_radius");
 	gtk_widget_set_sensitive (GTK_WIDGET (EdgesR), false);
 	Medians = (GtkCheckButton *) glade_xml_get_widget (xml, "medians");
 	g_signal_connect (G_OBJECT (Medians), "toggled", G_CALLBACK (on_medians_toggled), this);
-	MediansColor = (GtkColorButton *) glade_xml_get_widget (xml, "med_color");
+	MediansColor = (GtkColorButton *) glade_xml_get_widget (xml, "med-color");
 	gtk_widget_set_sensitive (GTK_WIDGET (MediansColor), false);
 	MediansR = (GtkEntry *) glade_xml_get_widget (xml, "med_radius");
 	gtk_widget_set_sensitive (GTK_WIDGET (MediansR), false);
 	Diags = (GtkCheckButton *) glade_xml_get_widget (xml, "diagonals");
 	g_signal_connect (G_OBJECT (Diags), "toggled", G_CALLBACK (on_diags_toggled), this);
-	DiagsColor = (GtkColorButton *) glade_xml_get_widget (xml, "diag_color");
+	DiagsColor = (GtkColorButton *) glade_xml_get_widget (xml, "diag-color");
 	gtk_widget_set_sensitive (GTK_WIDGET (DiagsColor), false);
 	DiagsR = (GtkEntry *) glade_xml_get_widget (xml, "diag_radius");
 	gtk_widget_set_sensitive (GTK_WIDGET (DiagsR), false);
